@@ -19,8 +19,10 @@ $(function() {
 		if (action == 'deleteuser') {
 			for (i=0; i<user_ids.length; i++) {
 				if (nb_posts[i] > 0) {
-					user_ids[i].checked = false;
-					msg_cannot_delete = true;
+					if (user_ids[i].checked == true) {
+						msg_cannot_delete = true;
+						user_ids[i].checked = false;
+					}
 				}
 			}
 			if (msg_cannot_delete == true) {
