@@ -10,16 +10,6 @@
 #
 # -- END LICENSE BLOCK -----------------------------------------
 
-/*== DC_DEBUG ==
-ini_set('display_errors',true);
-error_reporting(E_ALL | E_STRICT);
-define('DC_DEBUG',true);
-//*/
-
-if (!defined('DC_DEBUG')) {
-	define('DC_DEBUG',false);
-}
-
 /* ------------------------------------------------------------------------------------------- */
 #  ClearBricks, DotClear classes auto-loader
 if (@is_dir('/usr/lib/clearbricks')) {
@@ -42,6 +32,7 @@ $__autoload['dcCategories']			= dirname(__FILE__).'/core/class.dc.categories.php
 $__autoload['dcError']				= dirname(__FILE__).'/core/class.dc.error.php';
 $__autoload['dcMeta']				= dirname(__FILE__).'/core/class.dc.meta.php';
 $__autoload['dcMedia']				= dirname(__FILE__).'/core/class.dc.media.php';
+$__autoload['dcPostMedia']				= dirname(__FILE__).'/core/class.dc.postmedia.php';
 $__autoload['dcModules']				= dirname(__FILE__).'/core/class.dc.modules.php';
 $__autoload['dcThemes']				= dirname(__FILE__).'/core/class.dc.themes.php';
 $__autoload['dcRestServer']			= dirname(__FILE__).'/core/class.dc.rest.php';
@@ -115,9 +106,23 @@ if (!is_file(DC_RC_PATH))
 
 require DC_RC_PATH;
 
+/*== DC_DEBUG ==
+if (!defined('DC_DEBUG')) {
+	define('DC_DEBUG',true);
+}
+if (DC_DEBUG) {
+	ini_set('display_errors',true);
+	error_reporting(E_ALL | E_STRICT);
+}
+//*/
+
+if (!defined('DC_DEBUG')) {
+	define('DC_DEBUG',false);
+}
+
 # Constants
 define('DC_ROOT',path::real(dirname(__FILE__).'/..'));
-define('DC_VERSION','2.3.1');
+define('DC_VERSION','2.4.0');
 define('DC_DIGESTS',dirname(__FILE__).'/digests');
 define('DC_L10N_ROOT',dirname(__FILE__).'/../locales');
 define('DC_L10N_UPDATE_URL','http://services.dotclear.net/dc2.l10n/?version=%s');
